| problem | correct | time | if_read | audio_file | recognization | similarity
--- | --- | --- | --- | --- | --- | --- | ---
0 | １　开天辟地的神话 | 1 | 61 | False | E:/python2022/Chinese_reading_coach/chrc/chrc/L_record/20220806_170213.wav | 一开天辟地的神话 | 88
1 | 我们伟大祖国有非常悠久的历史。 | 1 | 27 | False | E:/python2022/Chinese_reading_coach/chrc/chrc/L_record/20220806_170308.wav | 我们伟大祖国有非常悠久的历史 | 100
2 | 按照古代的传统说法， | 1 | 17 | False | E:/python2022/Chinese_reading_coach/chrc/chrc/L_record/20220806_170329.wav | 按照古代的传统说法 | 100
3 | 从传说中的黄帝到现在， | 1 | 104 | True | E:/python2022/Chinese_reading_coach/chrc/chrc/L_record/20220806_170508.wav | 从传说中的皇帝到现在 | 90
4 | 大约有四千多年的历史， | 1 | 55 | False | E:/python2022/Chinese_reading_coach/chrc/chrc/L_record/20220806_170611.wav | 大约有4000多年的历史 | 73
5 | 通常叫做“上下五千年”。 | 1 | 204 | False | E:/python2022/Chinese_reading_coach/chrc/chrc/L_record/20220806_170939.wav | 春秋做上下五千年 | 71
6 | 在上下五千年的历史里， | 1 | 33 | False | E:/python2022/Chinese_reading_coach/chrc/chrc/L_record/20220806_171007.wav | 上下5000年的历史里 | 67
7 | 有许多动人的有意义的故事。 | 1 | 23 | False | E:/python2022/Chinese_reading_coach/chrc/chrc/L_record/20220806_171042.wav | 许多动人的游戏的故事 | 73
8 | 其中有许多是有文字记载的。 | 1 | 82 | True | E:/python2022/Chinese_reading_coach/chrc/chrc/L_record/20220806_171157.wav | 中有许多是有文字记载的 | 96
9 | 至于五千年以前远古时期的情况， | 1 | 7 | True | E:/python2022/Chinese_reading_coach/chrc/chrc/L_record/20220806_191543.wav | 至于5000年以前人古时期的情况 | 73